@@ -1,7 +1,7 @@
 /*PGR-GNU*****************************************************************
-File: edge_bool_t.h
+File: edge_bool_t_rt.h
 
-Copyright (c) 2017 pgRouting developers
+Copyright (c) 2015-2026 pgRouting developers
 Mail: project@pgrouting.org
 
 Copyright (c) 2017 Celia Virginia Vergara Castillo
