@@ -1,7 +1,7 @@
 /*PGR-GNU*****************************************************************
-File: pgr_types.h
+File: routes_t.h
 
-Copyright (c) 2015 pgRouting developers
+Copyright (c) 2015-2026 pgRouting developers
 Mail: project@pgrouting.org
 
 Copyright (c) 2015 Celia Virginia Vergara Castillo
